Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
ListenAddress string
Pool *pgxpool.Pool
DynamicClient apply.DynamicClientFactory
// ContextMiddleware sets up the request context with all loaders and
// dependencies needed by the apply handler (authz, activitylog, etc.).
// In production this is the middleware returned by ConfigureGraph.
// In tests a minimal equivalent can be provided.
ContextMiddleware func(http.Handler) http.Handler
JWTMiddleware func(http.Handler) http.Handler
GitHubOIDCMiddleware func(http.Handler) http.Handler
AuthHandler authn.Handler
Fakes Fakes
Log logrus.FieldLogger
}
Config holds all dependencies needed by the REST server.
Click to show internal directories.
Click to hide internal directories.